@@ -23,23 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQTEXTCODEC_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QTextCodec class
-// For Qt3, no changes are needed
-
 #include <ntqtextcodec.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QTextCodec class
-// For Qt4, some changes are needed
-
-#include <tqt4/Qt/ntqtextcodec.h>
-
-#endif // USE_QT4
-
 #endif /* TQT_TQTEXTCODEC_H */
